@@ -1,8 +1,8 @@
 import { pem, pki } from 'node-forge';
 
-import { SAMLFormData, SAMLStepKey } from '../../..//types';
 import { ValidationResult } from '../../../shared/types';
-import { samlSteps } from '../../index';
+import { SAMLFormData, SAMLStepKey } from '../../../types';
+import { samlSteps } from '../../steps';
 
 type ValidationFunc = (config: SAMLFormData) => ValidationResult;
 
@@ -74,13 +74,13 @@ export function validateConfigGeneral(config: SAMLFormData): ValidationResult {
 
 export function validateConfigKeyCert(config: SAMLFormData): ValidationResult {
   const validationRes: ValidationResult = { valid: true, errors: [] };
-  const { privateKey, privateKeyPath, certificate, certificatePath } = config;
+  const { signRequests, privateKey, privateKeyPath, certificate, certificatePath } = config;
 
-  if (!privateKey && !privateKeyPath) {
-    setValidationError(validationRes, 'Private key should be configured');
+  if (signRequests && !privateKey && !privateKeyPath) {
+    setValidationError(validationRes, 'Private key should be configured if sign requests is enabled');
   }
-  if (!certificate && !certificatePath) {
-    setValidationError(validationRes, 'Certificate key should be configured');
+  if (signRequests && !certificate && !certificatePath) {
+    setValidationError(validationRes, 'Certificate key should be configured if sign requests is enabled');
   }
   if (privateKey && !privateKey.startsWith('***') && !validateBase64PEMKey(privateKey)) {
     setValidationError(validationRes, 'Not valid PEM private key');
