@@ -1,6 +1,5 @@
 import { css } from '@emotion/css';
 import { isLastDayOfMonth } from 'date-fns';
-import React from 'react';
 import { useForm, Controller } from 'react-hook-form';
 import { connect, ConnectedProps } from 'react-redux';
 
@@ -10,7 +9,7 @@ import {
   DatePickerWithInput,
   Field,
   FieldSet,
-  HorizontalGroup,
+  Stack,
   Icon,
   Input,
   RadioButtonGroup,
@@ -186,7 +185,7 @@ export const Schedule = ({ report, updateReportProp, reportId }: Props) => {
 
         <>
           {watchFrequency === SchedulingFrequency.Custom && (
-            <HorizontalGroup>
+            <Stack>
               <Field label={'Repeat every'}>
                 <Input
                   type={'number'}
@@ -216,7 +215,7 @@ export const Schedule = ({ report, updateReportProp, reportId }: Props) => {
                   name={'schedule.intervalFrequency'}
                 />
               </Field>
-            </HorizontalGroup>
+            </Stack>
           )}
 
           {watchFrequency === SchedulingFrequency.Monthly &&
@@ -243,7 +242,7 @@ export const Schedule = ({ report, updateReportProp, reportId }: Props) => {
 
         {/*Hide date/time fields instead of completely removing them, so the timezone value doesn't get reset */}
         <div className={watchSendTime !== 'now' && watchFrequency !== SchedulingFrequency.Never ? '' : styles.hidden}>
-          <HorizontalGroup width={'100%'}>
+          <Stack>
             <Field label={'Start date'}>
               <Controller
                 name={'schedule.startDate'}
@@ -301,7 +300,7 @@ export const Schedule = ({ report, updateReportProp, reportId }: Props) => {
                 />
               </Field>
             </>
-          </HorizontalGroup>
+          </Stack>
         </div>
         {watchFrequency === SchedulingFrequency.Monthly &&
           !watchSendOnLastDayOfMonth &&
@@ -314,7 +313,7 @@ export const Schedule = ({ report, updateReportProp, reportId }: Props) => {
             </small>
           )}
         {![SchedulingFrequency.Once, SchedulingFrequency.Never].includes(watchFrequency) && (
-          <HorizontalGroup width={'100%'}>
+          <Stack>
             <Field label={'End date'}>
               <Controller
                 name={'schedule.endDate'}
@@ -361,7 +360,7 @@ export const Schedule = ({ report, updateReportProp, reportId }: Props) => {
                   />
                 </Field>
               )}
-          </HorizontalGroup>
+          </Stack>
         )}
 
         {showWorkdaysOnly(watchFrequency, watchIntervalFrequency) && (
@@ -373,10 +372,10 @@ export const Schedule = ({ report, updateReportProp, reportId }: Props) => {
             />
           </Field>
         )}
-        <div className={styles.schedulePreview}>
+        <Stack alignItems={'center'}>
           <Icon name={'calendar-alt'} />
           {schedulePreview({ ...defaultSchedule, ...watchSchedule })}
-        </div>
+        </Stack>
       </FieldSet>
     </ReportForm>
   );
@@ -386,21 +385,13 @@ export default connector(Schedule);
 
 const getStyles = (theme: GrafanaTheme2) => {
   return {
-    warningText: css`
-      color: ${theme.colors.warning.main};
-      display: block;
-      margin: -${theme.spacing(1)} 0 ${theme.spacing(3)} 0;
-    `,
-    hidden: css`
-      display: none;
-    `,
-    schedulePreview: css`
-      display: flex;
-      align-items: center;
-
-      svg {
-        margin-right: ${theme.spacing(1)};
-      }
-    `,
+    warningText: css({
+      color: theme.colors.warning.main,
+      display: 'block',
+      margin: theme.spacing(-1, 0, 3, 0),
+    }),
+    hidden: css({
+      display: 'none',
+    }),
   };
 };
