@@ -1,19 +1,20 @@
 import { css, cx } from '@emotion/css';
-import React, { useEffect } from 'react';
+import { useEffect } from 'react';
 import { Control, useFieldArray, useForm, UseFormSetValue, Controller } from 'react-hook-form';
 import { connect, ConnectedProps } from 'react-redux';
 
-import { GrafanaTheme2, isEmptyObject, RawTimeRange, TimeRange } from '@grafana/data';
+import { GrafanaTheme2, isEmptyObject, RawTimeRange, TimeRange, VariableHide } from '@grafana/data';
 import { Button, Field, FieldSet, InlineField, TimeRangeInput, useStyles2 } from '@grafana/ui';
 import { DashboardPicker, DashboardPickerDTO } from 'app/core/components/Select/DashboardPicker';
 import { variableAdapters } from 'app/features/variables/adapters';
 import { hasOptions } from 'app/features/variables/guard';
 import { cleanUpVariables } from 'app/features/variables/state/actions';
 import { getVariablesByKey } from 'app/features/variables/state/selectors';
-import { VariableHide, VariableModel } from 'app/features/variables/types';
+import { VariableModel } from 'app/features/variables/types';
 
 import { EnterpriseStoreState, ReportDashboard, ReportFormData, ReportTimeRange, StepKey } from '../../types';
 import { getRange, parseRange } from '../../utils/time';
+import { selectors } from '../e2e-selectors/selectors';
 import { initVariables } from '../state/actions';
 import { updateReportProp } from '../state/reducers';
 import { canEditReport } from '../utils/permissions';
@@ -187,6 +188,7 @@ export const SelectDashboards = ({ report, reportId, updateReportProp, initVaria
                   setValue={setValue}
                   selectedDashboards={watchDashboards}
                   onTimeRangeChange={onTimeRangeChange}
+                  dataTestId={selectors.components.reportForm.selectDashboard(index.toString())}
                 />
                 {fields.length > 1 && (
                   <Button
@@ -221,6 +223,7 @@ interface SelectDashboardProps {
   setValue: UseFormSetValue<{ dashboards: ReportDashboard[] }>;
   selectedDashboards: ReportDashboard[];
   onTimeRangeChange: (timeRange: RawTimeRange) => void;
+  dataTestId?: string;
 }
 
 export const SelectDashboard = ({
@@ -233,6 +236,7 @@ export const SelectDashboard = ({
   setValue,
   onTimeRangeChange,
   selectedDashboards = [],
+  dataTestId,
 }: SelectDashboardProps) => {
   const timeRange = getRange(field.timeRange);
   const reportVariables = variables.filter((v) => v.hide !== VariableHide.hideVariable);
@@ -253,13 +257,13 @@ export const SelectDashboard = ({
                 <DashboardPicker
                   {...fieldProps}
                   id={`dashboard-${index}`}
+                  data-testid={dataTestId}
                   aria-label={'Source dashboard'}
                   isClearable
                   value={value?.uid}
                   disabled={!canEditReport}
                   onChange={(dashboard) => {
-                    // Calling onChange with null is the correct way to reset selected value in react-hook-form
-                    onChange({ ...dashboard, name: dashboard?.title } || null);
+                    onChange({ ...dashboard, name: dashboard?.title });
                     onDashboardChange(dashboard, dashboardUid);
                   }}
                 />
@@ -348,22 +352,22 @@ const getTimeRange = (timeRange: ReportTimeRange, fallback: ReportTimeRange) =>
 
 const getStyles = (theme: GrafanaTheme2) => {
   return {
-    removeBtn: css`
-      margin-bottom: ${theme.spacing(2)};
-    `,
-    section: css`
-      padding-bottom: ${theme.spacing(2)};
-    `,
-    sectionBorder: css`
-      &:not(:last-of-type) {
-        border-bottom: 1px solid ${theme.colors.border.weak};
-        margin-bottom: ${theme.spacing(3)};
+    removeBtn: css({
+      marginBottom: theme.spacing(2),
+    }),
+    section: css({
+      paddingBottom: theme.spacing(2),
+    }),
+    sectionBorder: css({
+      '&:not(:last-of-type)': {
+        borderBottom: `1px solid ${theme.colors.border.weak}`,
+        marginBottom: theme.spacing(3),
       }
-    `,
-    infoText: css`
-      color: ${theme.colors.text.secondary};
-      font-size: ${theme.typography.size.sm};
-      font-weight: ${theme.typography.fontWeightRegular};
-    `,
+    }),
+    infoText: css({
+      color: theme.colors.text.secondary,
+      fontSize: theme.typography.size.sm,
+      fontWeight: theme.typography.fontWeightRegular,
+    }),
   };
 };
